@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gtksourceundomanager_defaultdefault.h
+ * gtksourceundomanagerdefault.h
  * This file is part of GtkSourceView
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
@@ -16,17 +16,17 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
-
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_UNDO_MANAGER_DEFAULT_H__
-#define __GTK_SOURCE_UNDO_MANAGER_DEFAULT_H__
+#ifndef GTK_SOURCE_UNDO_MANAGER_DEFAULT_H
+#define GTK_SOURCE_UNDO_MANAGER_DEFAULT_H
 
 #include <glib-object.h>
-#include <gtksourceview/gtksourcetypes.h>
+#include "gtksourcetypes-private.h"
 
 G_BEGIN_DECLS
 
@@ -52,13 +52,13 @@ struct _GtkSourceUndoManagerDefaultClass
 	GObjectClass parent_class;
 };
 
+G_GNUC_INTERNAL
 GType gtk_source_undo_manager_default_get_type (void) G_GNUC_CONST;
 
+G_GNUC_INTERNAL
 void gtk_source_undo_manager_default_set_max_undo_levels (GtkSourceUndoManagerDefault *manager,
                                                           gint                         max_undo_levels);
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_UNDO_MANAGER_DEFAULT_H__ */
-
-
+#endif /* GTK_SOURCE_UNDO_MANAGER_DEFAULT_H */
